<?php

namespace Drupal\self_evaluation\Controller;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\self_evaluation\SelfEvaluationInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for answers admin routes.
 */
class SelfEvaluationAnswersController extends SelfEvaluationListController {

  /**
   * Constructs a new SelfEvaluationAdminController.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Entity Type manager service.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;

  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new static(
      $container->get('entity_type.manager'),
    );
  }

  /**
   * Return Themes List for a self evaluation.
   *
   * @param \Drupal\self_evaluation\SelfEvaluationInterface $self_evaluation
   *   The current Self Evaluation Entity.
   *
   * @return array
   *   Array return.
   */
  public function buildList(SelfEvaluationInterface $self_evaluation): array {
    return [
      '#type' => 'html_tag',
      '#tag' => 'div',
      '#value' => "LA future liste des réponses.",
      '#attributes' => ['class' => ['']],
    ];
  }

  /**
   * Builds the header row for the entity listing.
   *
   * @return array
   *   A render array structure of header strings.
   *
   * @see \Drupal\Core\Entity\EntityListBuilder::render()
   */
  public function buildHeader(): array {
    $header['id'] = $this->t('ID');
    $header['title'] = $this->t('Title');
    $header['status'] = $this->t('Publishing status');
    return $header + parent::buildHeader();
  }

  /**
   * Builds a row for an entity in the entity listing.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity for this row of the list.
   *
   * @return array
   *   A render array structure of fields for this entity.
   *
   * @see \Drupal\Core\Entity\EntityListBuilder::render()
   */
  public function buildRow(EntityInterface $entity): array {
    $row['id']['data'] = $entity->id();
    $row['title']['data'] = $entity->label();
    $row['status']['data'] = $entity->isEnabled();
    return $row + parent::buildRow($entity);
  }

}
