<?php

namespace Drupal\self_evaluation\Controller;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Url;
use Drupal\self_evaluation\ActiveTrailTrait;
use Drupal\self_evaluation\Entity\SelfEvaluationQuestionChoice;
use Drupal\self_evaluation\SelfEvaluationQuestionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for questions choices admin routes.
 */
class SelfEvaluationQuestionChoicesController extends SelfEvaluationListController {

  use ActiveTrailTrait;

  /**
   * Constructs a new SelfEvaluationAdminController.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Entity Type manager service.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new static(
      $container->get('entity_type.manager'),
    );
  }

  /**
   * Return Themes List for a self evaluation.
   *
   * @param \Drupal\self_evaluation\SelfEvaluationQuestionInterface $self_evaluation_question
   *   The current question Entity.
   *
   * @return array
   *   Array return.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityMalformedException
   */
  public function buildList(SelfEvaluationQuestionInterface $self_evaluation_question): array {
    $rows = [];
    $list_choices = SelfEvaluationQuestionChoice::getChoicesFromQuestion($self_evaluation_question);

    if (!empty($list_choices)) {
      $themes = $this->entityTypeManager->getStorage('self_evaluation_question_choice')
        ->loadMultiple($list_choices);

      foreach ($themes as $theme) {
        $rows[] = $this->buildRow($theme);
      }
    }
    $build = $this->render();

    $build['build_active_trail'] = $this->buildActiveTrail($self_evaluation_question);
    $build['add']['#title'] = $this->t('Add a choice');
    $build['add']['#url'] = Url::fromRoute('entity.self_evaluation_question_choice.add_form', [], ['query' => ['self_evaluation_question' => $self_evaluation_question->id()]]);
    $build['list']['#empty'] = $this->t('There are no question choice yet.');
    $build['list']['#rows'] = $rows;
    return $build;
  }

  /**
   * Builds the header row for the entity listing.
   *
   * @return array
   *   A render array structure of header strings.
   *
   * @see \Drupal\Core\Entity\EntityListBuilder::render()
   */
  public function buildHeader(): array {
    $header['title'] = $this->t('Title');
    $header['note'] = $this->t('Note');
    $header['weight'] = $this->t('Weight');
    return $header + parent::buildHeader();
  }

  /**
   * Builds a row for an entity in the entity listing.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity for this row of the list.
   *
   * @return array
   *   A render array structure of fields for this entity.
   *
   * @see \Drupal\Core\Entity\EntityListBuilder::render()
   *
   * @todo modifier l'affichage du titre avec un view mode spécifique.
   */
  public function buildRow(EntityInterface $entity): array {
    $row['title']['data'] = $entity->get('title')->view(['label' => 'hidden']);
    $row['note']['data'] = $entity->note->value;
    $row['weight']['data'] = $entity->weight->value;
    return $row + parent::buildRow($entity);
  }

}
