<?php

namespace Drupal\self_evaluation\Controller;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Url;
use Drupal\self_evaluation\ActiveTrailTrait;
use Drupal\self_evaluation\Entity\SelfEvaluationThemeThreshold;
use Drupal\self_evaluation\SelfEvaluationThemeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for thresholds admin routes.
 */
class SelfEvaluationThresholdsController extends SelfEvaluationListController {

  use ActiveTrailTrait;

  /**
   * Constructs a new SelfEvaluationAdminController.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Entity Type manager service.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new static(
      $container->get('entity_type.manager'),
    );
  }

  /**
   * Return Threshold List for a theme.
   *
   * @param \Drupal\self_evaluation\SelfEvaluationThemeInterface $self_evaluation_theme
   *   The current Theme Entity.
   *
   * @return array
   *   Array return.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function buildList(SelfEvaluationThemeInterface $self_evaluation_theme): array {
    $rows = [];
    $list_thresholds = SelfEvaluationThemeThreshold::getThresholdsFromTheme($self_evaluation_theme);

    if (!empty($list_thresholds)) {
      $thresholds = $this->entityTypeManager->getStorage('self_evaluation_theme_threshold')
        ->loadMultiple($list_thresholds);

      foreach ($thresholds as $threshold) {
        $rows[] = $this->buildRow($threshold);
      }
    }
    $build = $this->render();

    $build['build_active_trail'] = $this->buildActiveTrail($self_evaluation_theme);
    $build['add']['#title'] = $this->t('Add Threshold');
    $build['add']['#url'] = Url::fromRoute('entity.self_evaluation_theme_threshold.add_form', [], ['query' => ['self_evaluation_theme' => $self_evaluation_theme->id()]]);
    $build['list']['#empty'] = $this->t('There are no threshold yet.');
    $build['list']['#rows'] = $rows;
    return $build;
  }

  /**
   * Builds the header row for the entity listing.
   *
   * @return array
   *   A render array structure of header strings.
   *
   * @see \Drupal\Core\Entity\EntityListBuilder::render()
   */
  public function buildHeader(): array {
    $header['title'] = $this->t('Title');
    $header['max_score'] = $this->t('Maximum Score');
    return $header + parent::buildHeader();
  }

  /**
   * Builds a row for an entity in the entity listing.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity for this row of the list.
   *
   * @return array
   *   A render array structure of fields for this entity.
   *
   * @see \Drupal\Core\Entity\EntityListBuilder::render()
   */
  public function buildRow(EntityInterface $entity): array {
    $row['title']['data'] = $entity->label();
    $row['max_score']['data'] = $entity->max_score->value;
    return $row + parent::buildRow($entity);
  }

}
