<?php

namespace Drupal\self_evaluation\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\self_evaluation\SelfComputedThematicScoreInterface;

/**
 * Defines the self evaluation computed thematic score entity class.
 *
 * @ContentEntityType(
 *   id = "self_computed_thematic_score",
 *   label = @Translation("Computed Thematic Score"),
 *   label_collection = @Translation("Computed Thematic Scores"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\self_evaluation\SelfComputedThematicScoreListBuilder",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *     "access" = "Drupal\self_evaluation\SelfComputedThematicScoreAccessControlHandler",
 *     "form" = {
 *       "add" = "Drupal\self_evaluation\Form\SelfComputedThematicScoreForm",
 *       "edit" = "Drupal\self_evaluation\Form\SelfComputedThematicScoreForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\AdminHtmlRouteProvider",
 *     }
 *   },
 *   base_table = "self_computed_thematic_score",
 *   data_table = "self_computed_thematic_score_field_data",
 *   admin_permission = "administer self evaluation computed thematic score",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "id",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "add-form" = "/admin/self-evaluation/content/self-evaluation-computed-thematic-score/add",
 *     "canonical" = "/self_computed_thematic_score/{self_computed_thematic_score}",
 *     "edit-form" = "/admin/self-evaluation/content/self-evaluation-computed-thematic-score/{self_computed_thematic_score}/edit",
 *     "delete-form" = "/admin/self-evaluation/content/self-evaluation-computed-thematic-score/{self_computed_thematic_score}/delete",
 *     "collection" = "/admin/self-evaluation/content/self-evaluation-computed-thematic-score"
 *   },
 *   field_ui_base_route = "entity.self_computed_thematic_score.settings"
 * )
 */
class SelfComputedThematicScore extends ContentEntityBase implements SelfComputedThematicScoreInterface {

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {

    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['self_evaluation_theme'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Theme'))
      ->setDescription(t(''))
      ->setRequired(TRUE)
      ->setSetting('target_type', 'self_evaluation_theme')
      ->setDisplayOptions('form', [
        'type' => 'entity_reference_autocomplete',
        'settings' => [
          'match_operator' => 'CONTAINS',
          'size' => 60,
          'placeholder' => '',
        ],
        'weight' => -5,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayOptions('view', [
        'label' => 'above',
        'weight' => -5,
      ])
      ->setDisplayConfigurable('view', TRUE);

    $fields['score'] = BaseFieldDefinition::create('decimal')
      ->setTranslatable(TRUE)
      ->setLabel(t('Score'))
      ->setDescription(t(''))
      ->setRequired(TRUE)
      ->setSetting('precision', 10)
      ->setSetting('scale', 2)
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => 'number_decimal',
        'weight' => -4,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setDisplayOptions('form', [
        'type' => 'number',
        'settings' => [
          'display_label' => TRUE,
          'size' => 5,
        ],
        'weight' => -4,
      ])
      ->setDisplayConfigurable('view', TRUE);

    return $fields;
  }

}
