<?php

namespace Drupal\self_evaluation\Form;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Form controller for the self evaluation theme entity edit forms.
 */
class SelfEvaluationThemeForm extends ContentEntityForm {

  /**
   * Constructs a ContentEntityForm object.
   *
   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
   *   The entity repository service.
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entity_type_bundle_info
   *   The entity type bundle service.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The time service.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The route match service.
   */
  public function __construct(EntityRepositoryInterface $entity_repository, EntityTypeBundleInfoInterface $entity_type_bundle_info, TimeInterface $time, RequestStack $request_stack) {
    parent::__construct($entity_repository, $entity_type_bundle_info, $time);
    $this->requestStack = $request_stack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity.repository'),
      $container->get('entity_type.bundle.info'),
      $container->get('datetime.time'),
      $container->get('request_stack'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state): array {
    $form = parent::form($form, $form_state);

    if (!empty($this->requestStack->getCurrentRequest()->query) && !empty($this->requestStack->getCurrentRequest()->query->get('self_evaluation'))) {
      $self_evaluation = $this->entityTypeManager->getStorage('self_evaluation')
        ->load($this->requestStack->getCurrentRequest()->query->get('self_evaluation'));
      $form['self_evaluation']['widget'][0]['target_id']['#default_value'] = $self_evaluation;
      $form['self_evaluation']['#access'] = FALSE;
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {

    $entity = $this->getEntity();
    $result = $entity->save();
    $link = $entity->toLink($this->t('View'))->toRenderable();

    $message_arguments = ['%label' => $this->entity->label()];
    $logger_arguments = $message_arguments + ['link' => render($link)];

    if ($result == SAVED_NEW) {
      $this->messenger()
        ->addStatus($this->t('New self evaluation theme %label has been created.', $message_arguments));
      $this->logger('self_evaluation_theme')
        ->notice('Created new self evaluation theme %label', $logger_arguments);
    }
    else {
      $this->messenger()
        ->addStatus($this->t('The self evaluation theme %label has been updated.', $message_arguments));
      $this->logger('self_evaluation_theme')
        ->notice('Updated new self evaluation theme %label.', $logger_arguments);
    }

    $form_state->setRedirect('entity.self_evaluation.themes', ['self_evaluation' => $entity->self_evaluation->entity->id()]);
  }

}
