<?php

namespace Drupal\self_evaluation;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\user\EntityOwnerInterface;
use Drupal\Core\Entity\EntityChangedInterface;

/**
 * Provides an interface defining a self evaluation entity type.
 */
interface SelfEvaluationInterface extends ContentEntityInterface, EntityOwnerInterface, EntityChangedInterface {

  /**
   * Gets the self evaluation title.
   *
   * @return string
   *   Title of the self evaluation.
   */
  public function getTitle();

  /**
   * Sets the self evaluation title.
   *
   * @param string $title
   *   The self evaluation title.
   *
   * @return \Drupal\self_evaluation\SelfEvaluationInterface
   *   The called self evaluation entity.
   */
  public function setTitle($title);

  /**
   * Gets the self evaluation creation timestamp.
   *
   * @return int
   *   Creation timestamp of the self evaluation.
   */
  public function getCreatedTime();

  /**
   * Sets the self evaluation creation timestamp.
   *
   * @param int $timestamp
   *   The self evaluation creation timestamp.
   *
   * @return \Drupal\self_evaluation\SelfEvaluationInterface
   *   The called self evaluation entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the self evaluation status.
   *
   * @return bool
   *   TRUE if the self evaluation is enabled, FALSE otherwise.
   */
  public function isEnabled();

  /**
   * Sets the self evaluation status.
   *
   * @param bool $status
   *   TRUE to enable this self evaluation, FALSE to disable.
   *
   * @return \Drupal\self_evaluation\SelfEvaluationInterface
   *   The called self evaluation entity.
   */
  public function setStatus($status);

  /**
   * Get the publishable status.
   *
   * @return bool
   *   TRUE whether published, or FALSE if not.
   */
  public function isPublishable(): bool;

  /**
   * Get the researchable status.
   *
   * @return bool
   *   TRUE whether researchable, or FALSE if not.
   */
  public function isResearchable(): bool;

}
