<?php

namespace Drupal\self_evaluation;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the access control handler for the self evaluation reminder entity type.
 */
class SelfEvaluationReminderAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {

    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermission($account, 'view self evaluation reminder');

      case 'update':
        return AccessResult::allowedIfHasPermissions($account, ['edit self evaluation reminder', 'administer self evaluation reminder'], 'OR');

      case 'delete':
        return AccessResult::allowedIfHasPermissions($account, ['delete self evaluation reminder', 'administer self evaluation reminder'], 'OR');

      default:
        // No opinion.
        return AccessResult::neutral();
    }

  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermissions($account, ['create self evaluation reminder', 'administer self evaluation reminder'], 'OR');
  }

}
